//Source file: AddSagMembersConflict.java
//Date: June 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw;

/**
 * This data type is a Sequence of Data Elements which describes a conflict that may occur when client applications are added to a SAG - see method addSagMembers(). This happens, when a client application is assigned to a service twice. 
The AlreadyAssignedSagProfilePair describes the SAG and the service profile through which the client application is already assigned to the service. It includes the current service profile. The ConflictGeneratingSagProfilePair describes another SAG, to which the client application should be added, and the corresponding service profile, through which the client application is also connected to this service. This creates a conflict, as there may exist only a single service profile for each service.
 * 
 */
public final class AddSagMembersConflict implements java.io.Serializable {

    private String clientApplication;
    private org.csapi.jr.se.fw.SagProfilePair conflictGeneratingSagProfilePair;
    private org.csapi.jr.se.fw.SagProfilePair alreadyAssignedSagProfilePair;
    private String service;

    /**
     * Creates a new AddSagMembersConflict instance.
     */
    public AddSagMembersConflict () {}

    /**
     * Creates a new AddSagMembersConflict instance.
     * @param _clientApplication   
     * @param _conflictGeneratingSagProfilePair   
     * @param _alreadyAssignedSagProfilePair   
     * @param _service   
     */
    public AddSagMembersConflict (String _clientApplication, org.csapi.jr.se.fw.SagProfilePair _conflictGeneratingSagProfilePair, org.csapi.jr.se.fw.SagProfilePair _alreadyAssignedSagProfilePair, String _service) {

        this.clientApplication = _clientApplication;
        this.conflictGeneratingSagProfilePair = _conflictGeneratingSagProfilePair;
        this.alreadyAssignedSagProfilePair = _alreadyAssignedSagProfilePair;
        this.service = _service;
    }

    /**
     * This method returns a clientApplication.
     * 
     * @return a String value
     */
    public String getClientApplication() {
        return clientApplication;
    }

    /**
     * This method returns a conflictGeneratingSagProfilePair.
     * 
     * @return a org.csapi.jr.se.fw.SagProfilePair value
     */
    public org.csapi.jr.se.fw.SagProfilePair getConflictGeneratingSagProfilePair() {
        return conflictGeneratingSagProfilePair;
    }

    /**
     * This method returns a alreadyAssignedSagProfilePair.
     * 
     * @return a org.csapi.jr.se.fw.SagProfilePair value
     */
    public org.csapi.jr.se.fw.SagProfilePair getAlreadyAssignedSagProfilePair() {
        return alreadyAssignedSagProfilePair;
    }

    /**
     * This method returns a service.
     * 
     * @return a String value
     */
    public String getService() {
        return service;
    }


    /**
     * This method sets a clientApplication.
     */ 
    public void setClientApplication(String clientApplication) {
        this.clientApplication = clientApplication;
    }

    /**
     * This method sets a conflictGeneratingSagProfilePair.
     */ 
    public void setConflictGeneratingSagProfilePair(org.csapi.jr.se.fw.SagProfilePair conflictGeneratingSagProfilePair) {
        this.conflictGeneratingSagProfilePair = conflictGeneratingSagProfilePair;
    }

    /**
     * This method sets a alreadyAssignedSagProfilePair.
     */ 
    public void setAlreadyAssignedSagProfilePair(org.csapi.jr.se.fw.SagProfilePair alreadyAssignedSagProfilePair) {
        this.alreadyAssignedSagProfilePair = alreadyAssignedSagProfilePair;
    }

    /**
     * This method sets a service.
     */ 
    public void setService(String service) {
        this.service = service;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AddSagMembersConflict)) {
            return false;
        } 
        AddSagMembersConflict addSagMembersConflict = (AddSagMembersConflict) o;
        if(!(this.clientApplication == addSagMembersConflict.clientApplication))  {
            return false;
        }
        if ((this.conflictGeneratingSagProfilePair != null) && (addSagMembersConflict.conflictGeneratingSagProfilePair != null)) {
            if(!(this.conflictGeneratingSagProfilePair.equals(addSagMembersConflict.conflictGeneratingSagProfilePair))) {
                return false;
            }
        }
        if ((this.alreadyAssignedSagProfilePair != null) && (addSagMembersConflict.alreadyAssignedSagProfilePair != null)) {
            if(!(this.alreadyAssignedSagProfilePair.equals(addSagMembersConflict.alreadyAssignedSagProfilePair))) {
                return false;
            }
        }
        if(!(this.service == addSagMembersConflict.service))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AddSagMembersConflict

