//Source file: FaultStats.java
//Date: June 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw;

/**
 * This defines the sequence of data elements which provide the statistics on a per fault type basis. 
Occurrences is the number of separate instances of this fault during the period. MaxDuration and TotalDuration are the number of seconds duration of the longest fault and the cumulative total during the period. NumberOfClientsAffected is the number of clients informed of the fault by the Framework. 
 * 
 */
public final class FaultStats implements java.io.Serializable {

    private org.csapi.jr.se.fw.InterfaceFault fault;
    private int occurrences;
    private int maxDuration;
    private int totalDuration;
    private int numberOfClientsAffected;

    /**
     * Creates a new FaultStats instance.
     */
    public FaultStats () {}

    /**
     * Creates a new FaultStats instance.
     * @param _fault   
     * @param _occurrences   The number of separate instances of this fault
     * @param _maxDuration   The number of seconds duration of the longest fault
     * @param _totalDuration   The cumulative duration (all occurrences)
     * @param _numberOfClientsAffected   The number of clients informed of the fault by the Fw
     */
    public FaultStats (org.csapi.jr.se.fw.InterfaceFault _fault, int _occurrences, int _maxDuration, int _totalDuration, int _numberOfClientsAffected) {

        this.fault = _fault;
        this.occurrences = _occurrences;
        this.maxDuration = _maxDuration;
        this.totalDuration = _totalDuration;
        this.numberOfClientsAffected = _numberOfClientsAffected;
    }

    /**
     * This method returns a fault.
     * 
     * @return a org.csapi.jr.se.fw.InterfaceFault value
     */
    public org.csapi.jr.se.fw.InterfaceFault getFault() {
        return fault;
    }

    /**
     * This method returns a occurrences.
     * 
     * @return a int value
     */
    public int getOccurrences() {
        return occurrences;
    }

    /**
     * This method returns a maxDuration.
     * 
     * @return a int value
     */
    public int getMaxDuration() {
        return maxDuration;
    }

    /**
     * This method returns a totalDuration.
     * 
     * @return a int value
     */
    public int getTotalDuration() {
        return totalDuration;
    }

    /**
     * This method returns a numberOfClientsAffected.
     * 
     * @return a int value
     */
    public int getNumberOfClientsAffected() {
        return numberOfClientsAffected;
    }


    /**
     * This method sets a fault.
     */ 
    public void setFault(org.csapi.jr.se.fw.InterfaceFault fault) {
        this.fault = fault;
    }

    /**
     * This method sets a occurrences.
     */ 
    public void setOccurrences(int occurrences) {
        this.occurrences = occurrences;
    }

    /**
     * This method sets a maxDuration.
     */ 
    public void setMaxDuration(int maxDuration) {
        this.maxDuration = maxDuration;
    }

    /**
     * This method sets a totalDuration.
     */ 
    public void setTotalDuration(int totalDuration) {
        this.totalDuration = totalDuration;
    }

    /**
     * This method sets a numberOfClientsAffected.
     */ 
    public void setNumberOfClientsAffected(int numberOfClientsAffected) {
        this.numberOfClientsAffected = numberOfClientsAffected;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof FaultStats)) {
            return false;
        } 
        FaultStats faultStats = (FaultStats) o;
        if ((this.fault != null) && (faultStats.fault != null)) {
            if(!(this.fault.equals(faultStats.fault))) {
                return false;
            }
        }
        if(!(this.occurrences == faultStats.occurrences)) {
            return false;
        }
        if(!(this.maxDuration == faultStats.maxDuration)) {
            return false;
        }
        if(!(this.totalDuration == faultStats.totalDuration)) {
            return false;
        }
        if(!(this.numberOfClientsAffected == faultStats.numberOfClientsAffected)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // FaultStats

