//Source file: FwEventName.java
//Date: June 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw;

/**
 * Defines the name of event being notified.
 *
 */
public final class FwEventName implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static FwEventName[] _array = new FwEventName[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private FwEventName(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined.
     */
    public static final int _EVENT_FW_NAME_UNDEFINED =  0;

    /**
     * Undefined.
     */
    public static final FwEventName EVENT_FW_NAME_UNDEFINED = new FwEventName(_EVENT_FW_NAME_UNDEFINED);

    /**
     * Notification of SCS(s) available.
     */
    public static final int _EVENT_FW_SERVICE_AVAILABLE =  1;

    /**
     * Notification of SCS(s) available.
     */
    public static final FwEventName EVENT_FW_SERVICE_AVAILABLE = new FwEventName(_EVENT_FW_SERVICE_AVAILABLE);

    /**
     * Notification of SCS(s) becoming unavailable.
     */
    public static final int _EVENT_FW_SERVICE_UNAVAILABLE =  2;

    /**
     * Notification of SCS(s) becoming unavailable.
     */
    public static final FwEventName EVENT_FW_SERVICE_UNAVAILABLE = new FwEventName(_EVENT_FW_SERVICE_UNAVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved FwEventName object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the FwEventName object
     */
    public String getValueText() {
        switch (_value) {
            case _EVENT_FW_NAME_UNDEFINED:
                return "EVENT_FW_NAME_UNDEFINED";
            case _EVENT_FW_SERVICE_AVAILABLE:
                return "EVENT_FW_SERVICE_AVAILABLE";
            case _EVENT_FW_SERVICE_UNAVAILABLE:
                return "EVENT_FW_SERVICE_UNAVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static FwEventName getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof FwEventName)) {
            return false;
        }
        FwEventName fwEventName = (FwEventName) o; 
        if(!(this.getValue() == fwEventName.getValue())) {
            return false;
        }
        if (this.hashCode() != fwEventName.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // FwEventName

