//Source file: InitialFactory.java
//Date: June 2004
//Interfaces and events produced for the Java Realisation of the 3GPP Release 5 API

package org.csapi.jr.se.fw;

/**
 * This factory class allows applications to obtain proprietary peer API objects.<br>
 * The term "peer" is Java nomenclature for a particular platform-specific implementation of a Java interface.
 * 
 */
public class InitialFactory {

    private static InitialFactory myFactory;
    private static String className = null;
    private static String lang      = "en";
    private static String cntry     = "US";

    private InitialFactory() {
    }

    /**
     * This method creates a new instance of the Initial
     *
     * @return  the instance of the factory object	
     * @param   initialPeerReference  reference to the initial
     * @exception  org.csapi.jr.se.PeerUnavailableException  if access to an implementation of the Initial interface has failed 
     * @exception  org.csapi.jr.se.ResourcesUnavailableException  if a physical resource in the network is not available
     * @exception  org.csapi.jr.se.InvalidArgumentException  if an invalid argument is set
     *
     */		
    public synchronized org.csapi.jr.se.fw.fw_access.trust_and_security.Initial createInitial(String initialPeerReference) 
        throws org.csapi.jr.se.PeerUnavailableException,
    	    org.csapi.jr.se.ResourcesUnavailableException,
    	    org.csapi.jr.se.InvalidArgumentException {

	java.util.Locale currentLocale;
	java.util.ResourceBundle messages;
	String tryMessage;

	try {
	    currentLocale = new java.util.Locale (lang, cntry);
	    messages = java.util.ResourceBundle.getBundle("InitialFactoryBundle", currentLocale);

	    // Validate all used values before using them later
	    // avoiding error text exception to hide the real exception	

	    tryMessage = messages.getString("InitialPeerReferenceNull");
	    tryMessage = messages.getString("InitialInstFailure");
	    tryMessage = messages.getString("DestroyInitialFailure");
	}
	catch (Exception e) {
	    throw new org.csapi.jr.se.ResourcesUnavailableException ("Localisation failed to initialize");	
	}

	if (initialPeerReference == null) {
	    String errmsg = messages.getString("InitialPeerReferenceNull");
	    throw new org.csapi.jr.se.InvalidArgumentException (errmsg);
	}

	try {
	    Class c = Class.forName (getImplementationClassName());
	    if (initialPeerReference.equals("")) {
		// Creates a new instance of the Object class
		// using a default constructor
		return (org.csapi.jr.se.fw.fw_access.trust_and_security.Initial) c.newInstance();
	    }

	    Class[] paramTypes = {initialPeerReference.getClass()};
	    java.lang.reflect.Constructor ctor = c.getConstructor(paramTypes);
	    Object[] params = {initialPeerReference};
	    return (org.csapi.jr.se.fw.fw_access.trust_and_security.Initial) ctor.newInstance(params);
	} 
	catch (Exception e) {	
	    String errmsg = messages.getString("InitialInstFailure");
	    throw new org.csapi.jr.se.PeerUnavailableException (errmsg);
	}
    }
		
    /**
     * This method gets a new instance 
     *
     */
    public synchronized static InitialFactory getInstance() {
	if (myFactory == null) {
	    myFactory = new InitialFactory();
    	}
	return myFactory;
    }

    /**
     * This method gets a new implementation class name
     *
     */
    public String getImplementationClassName() {
	return className;
    }

    /**
     * This method sets a new implementation class name
     *
     */
    public static void setImplementationClassName(String _className) {
	className = _className; 
    }

    /**
     * This method sets a locale
     *
     */
    public synchronized static void setLocale(String language, String country) {
	if (language == null) {
	    lang = "en";
	}
	else {
	    lang = language;
	}

	if (country == null) {
	    cntry = "US";
	}
	else {
	    cntry = country;
	}
    }

    /**
     * This method destroys the initial instance
     * @param   initialInstance  reference to the initial instance
     *
     */
    public void destroyInitial(org.csapi.jr.se.fw.fw_access.trust_and_security.Initial initialInstance) {
	initialInstance = null;
    }

} //InitialFactory 

