//Source file: InterfaceFault.java
//Date: June 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw;

/**
 * Defines the cause of the interface fault detected.
 *
 */
public final class InterfaceFault implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static InterfaceFault[] _array = new InterfaceFault[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private InterfaceFault(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _INTERFACE_FAULT_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final InterfaceFault INTERFACE_FAULT_UNDEFINED = new InterfaceFault(_INTERFACE_FAULT_UNDEFINED);

    /**
     * A fault in the local API software or hardware has been detected
     */
    public static final int _INTERFACE_FAULT_LOCAL_FAILURE =  1;

    /**
     * A fault in the local API software or hardware has been detected
     */
    public static final InterfaceFault INTERFACE_FAULT_LOCAL_FAILURE = new InterfaceFault(_INTERFACE_FAULT_LOCAL_FAILURE);

    /**
     * A fault in the gateway API software or hardware has been detected
     */
    public static final int _INTERFACE_FAULT_GATEWAY_FAILURE =  2;

    /**
     * A fault in the gateway API software or hardware has been detected
     */
    public static final InterfaceFault INTERFACE_FAULT_GATEWAY_FAILURE = new InterfaceFault(_INTERFACE_FAULT_GATEWAY_FAILURE);

    /**
     * An error in the protocol used on the client-gateway link has been detected
     */
    public static final int _INTERFACE_FAULT_PROTOCOL_ERROR =  3;

    /**
     * An error in the protocol used on the client-gateway link has been detected
     */
    public static final InterfaceFault INTERFACE_FAULT_PROTOCOL_ERROR = new InterfaceFault(_INTERFACE_FAULT_PROTOCOL_ERROR);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved InterfaceFault object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the InterfaceFault object
     */
    public String getValueText() {
        switch (_value) {
            case _INTERFACE_FAULT_UNDEFINED:
                return "INTERFACE_FAULT_UNDEFINED";
            case _INTERFACE_FAULT_LOCAL_FAILURE:
                return "INTERFACE_FAULT_LOCAL_FAILURE";
            case _INTERFACE_FAULT_GATEWAY_FAILURE:
                return "INTERFACE_FAULT_GATEWAY_FAILURE";
            case _INTERFACE_FAULT_PROTOCOL_ERROR:
                return "INTERFACE_FAULT_PROTOCOL_ERROR";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static InterfaceFault getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof InterfaceFault)) {
            return false;
        }
        InterfaceFault interfaceFault = (InterfaceFault) o; 
        if(!(this.getValue() == interfaceFault.getValue())) {
            return false;
        }
        if (this.hashCode() != interfaceFault.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // InterfaceFault

