//Source file: ServiceContractDescription.java
//Date: June 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw;

/**
 * This data type is a Sequence of Data Elements which describes a service contract. This contract should conform to a previously negotiated high-level agreement (regarding OSA services, their usage and the price, etc.), if any, between the enterprise operator and the framework operator.
Note: The InUse flag indicates if the contract, or one of its associated profiles, is currently in use by a service instance and will be returned in describeServiceContract().  This flag will be ignored if it is passed in to createServiceContract().
 * 
 */
public final class ServiceContractDescription implements java.io.Serializable {

    private org.csapi.jr.se.fw.Person serviceRequestor;
    private org.csapi.jr.se.fw.Person billingContact;
    private String serviceStartDate;
    private String serviceEndDate;
    private String serviceTypeName;
    private String serviceID;
    private org.csapi.jr.se.fw.ServiceProperty[] serviceSubscriptionProperties;
    private boolean inUse;

    /**
     * Creates a new ServiceContractDescription instance.
     */
    public ServiceContractDescription () {}

    /**
     * Creates a new ServiceContractDescription instance.
     * @param _serviceRequestor   
     * @param _billingContact   
     * @param _serviceStartDate   
     * @param _serviceEndDate   
     * @param _serviceTypeName   
     * @param _serviceID   
     * @param _serviceSubscriptionProperties   
     * @param _inUse   
     */
    public ServiceContractDescription (org.csapi.jr.se.fw.Person _serviceRequestor, org.csapi.jr.se.fw.Person _billingContact, String _serviceStartDate, String _serviceEndDate, String _serviceTypeName, String _serviceID, org.csapi.jr.se.fw.ServiceProperty[] _serviceSubscriptionProperties, boolean _inUse) {

        this.serviceRequestor = _serviceRequestor;
        this.billingContact = _billingContact;
        this.serviceStartDate = _serviceStartDate;
        this.serviceEndDate = _serviceEndDate;
        this.serviceTypeName = _serviceTypeName;
        this.serviceID = _serviceID;
        this.serviceSubscriptionProperties = _serviceSubscriptionProperties;
        this.inUse = _inUse;
    }

    /**
     * Creates a new ServiceContractDescription instance.
     * @param _serviceRequestor   
     * @param _billingContact   
     * @param _serviceStartDate   
     * @param _serviceEndDate   
     * @param _serviceTypeName   
     * @param _serviceID   
     * @param _serviceSubscriptionProperties   
     *
     * @deprecated  This method is deprecated and will be removed in a later release.
     * It is strongly recommended not to implement this method. 
     */
    public ServiceContractDescription (org.csapi.jr.se.fw.Person _serviceRequestor, org.csapi.jr.se.fw.Person _billingContact, String _serviceStartDate, String _serviceEndDate, String _serviceTypeName, String _serviceID, org.csapi.jr.se.fw.ServiceProperty[] _serviceSubscriptionProperties) {

        this.serviceRequestor = _serviceRequestor;
        this.billingContact = _billingContact;
        this.serviceStartDate = _serviceStartDate;
        this.serviceEndDate = _serviceEndDate;
        this.serviceTypeName = _serviceTypeName;
        this.serviceID = _serviceID;
        this.serviceSubscriptionProperties = _serviceSubscriptionProperties;
    }

    /**
     * This method returns a serviceRequestor.
     * 
     * @return a org.csapi.jr.se.fw.Person value
     */
    public org.csapi.jr.se.fw.Person getServiceRequestor() {
        return serviceRequestor;
    }

    /**
     * This method returns a billingContact.
     * 
     * @return a org.csapi.jr.se.fw.Person value
     */
    public org.csapi.jr.se.fw.Person getBillingContact() {
        return billingContact;
    }

    /**
     * This method returns a serviceStartDate.
     * 
     * @return a String value
     */
    public String getServiceStartDate() {
        return serviceStartDate;
    }

    /**
     * This method returns a serviceEndDate.
     * 
     * @return a String value
     */
    public String getServiceEndDate() {
        return serviceEndDate;
    }

    /**
     * This method returns a serviceTypeName.
     * 
     * @return a String value
     */
    public String getServiceTypeName() {
        return serviceTypeName;
    }

    /**
     * This method returns a serviceID.
     * 
     * @return a String value
     */
    public String getServiceID() {
        return serviceID;
    }

    /**
     * This method returns a serviceSubscriptionProperties.
     * 
     * @return a org.csapi.jr.se.fw.ServiceProperty[] value
     */
    public org.csapi.jr.se.fw.ServiceProperty[] getServiceSubscriptionProperties() {
        return serviceSubscriptionProperties;
    }

    /**
     * This method returns a inUse.
     * 
     * @return a boolean value
     */
    public boolean getInUse() {
        return inUse;
    }


    /**
     * This method sets a serviceRequestor.
     */ 
    public void setServiceRequestor(org.csapi.jr.se.fw.Person serviceRequestor) {
        this.serviceRequestor = serviceRequestor;
    }

    /**
     * This method sets a billingContact.
     */ 
    public void setBillingContact(org.csapi.jr.se.fw.Person billingContact) {
        this.billingContact = billingContact;
    }

    /**
     * This method sets a serviceStartDate.
     */ 
    public void setServiceStartDate(String serviceStartDate) {
        this.serviceStartDate = serviceStartDate;
    }

    /**
     * This method sets a serviceEndDate.
     */ 
    public void setServiceEndDate(String serviceEndDate) {
        this.serviceEndDate = serviceEndDate;
    }

    /**
     * This method sets a serviceTypeName.
     */ 
    public void setServiceTypeName(String serviceTypeName) {
        this.serviceTypeName = serviceTypeName;
    }

    /**
     * This method sets a serviceID.
     */ 
    public void setServiceID(String serviceID) {
        this.serviceID = serviceID;
    }

    /**
     * This method sets a serviceSubscriptionProperties.
     */ 
    public void setServiceSubscriptionProperties(org.csapi.jr.se.fw.ServiceProperty[] serviceSubscriptionProperties) {
        this.serviceSubscriptionProperties = serviceSubscriptionProperties;
    }

    /**
     * This method sets a inUse.
     */ 
    public void setInUse(boolean inUse) {
        this.inUse = inUse;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ServiceContractDescription)) {
            return false;
        } 
        ServiceContractDescription serviceContractDescription = (ServiceContractDescription) o;
        if(!(this.serviceRequestor == serviceContractDescription.serviceRequestor))  {
            return false;
        }
        if(!(this.billingContact == serviceContractDescription.billingContact))  {
            return false;
        }
        if(!(this.serviceStartDate == serviceContractDescription.serviceStartDate))  {
            return false;
        }
        if(!(this.serviceEndDate == serviceContractDescription.serviceEndDate))  {
            return false;
        }
        if(!(this.serviceSubscriptionProperties == serviceContractDescription.serviceSubscriptionProperties))  {
            return false;
        }
        if(!(this.serviceID == serviceContractDescription.serviceID))  {
            return false;
        }
        if(!(this.serviceTypeName == serviceContractDescription.serviceTypeName))  {
            return false;
        }
        if(!(this.inUse == serviceContractDescription.inUse)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ServiceContractDescription

