//Source file: SvcAvailStatusReason.java
//Date: June 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw;

/**
 * Defines the reason detailing the change in status of Service Instance availability.
Note 1:	The client application must act to reset its use of the specified service instance (using the normal mechanisms, such as the discovery and authentication interfaces, to stop use of this service instance and begin use of a different service instance).
Note 2: 	The "expected" recovery time could be defined within the SLA.
 *
 */
public final class SvcAvailStatusReason implements java.io.Serializable {

    private int _value;
    private static int _size = 8;
    private static SvcAvailStatusReason[] _array = new SvcAvailStatusReason[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private SvcAvailStatusReason(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined. A permanent failure.
     */
    public static final int _SVC_UNAVAILABLE_UNDEFINED =  0;

    /**
     * Undefined. A permanent failure.
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_UNDEFINED = new SvcAvailStatusReason(_SVC_UNAVAILABLE_UNDEFINED);

    /**
     * The Local API software or hardware has failed. A permanent failure.  See Note 1.
     */
    public static final int _SVC_UNAVAILABLE_LOCAL_FAILURE =  1;

    /**
     * The Local API software or hardware has failed. A permanent failure.  See Note 1.
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_LOCAL_FAILURE = new SvcAvailStatusReason(_SVC_UNAVAILABLE_LOCAL_FAILURE);

    /**
     * The gateway API software or hardware has failed. A permanent failure.  See Note 1.
     */
    public static final int _SVC_UNAVAILABLE_GATEWAY_FAILURE =  2;

    /**
     * The gateway API software or hardware has failed. A permanent failure.  See Note 1.
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_GATEWAY_FAILURE = new SvcAvailStatusReason(_SVC_UNAVAILABLE_GATEWAY_FAILURE);

    /**
     * The Service Instance is fully overloaded. A temporary problem.  See Note 2.
     */
    public static final int _SVC_UNAVAILABLE_OVERLOADED =  3;

    /**
     * The Service Instance is fully overloaded. A temporary problem.  See Note 2.
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_OVERLOADED = new SvcAvailStatusReason(_SVC_UNAVAILABLE_OVERLOADED);

    /**
     * The Service Instance has closed itself (for example to protect from fraud or malicious attack).  A permanent failure.  See Note 1
     */
    public static final int _SVC_UNAVAILABLE_CLOSED =  4;

    /**
     * The Service Instance has closed itself (for example to protect from fraud or malicious attack).  A permanent failure.  See Note 1
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_CLOSED = new SvcAvailStatusReason(_SVC_UNAVAILABLE_CLOSED);

    /**
     * The Framework has detected that a Service Instance has failed: for example non-response from an activity test, failure to return heartbeats. A permanent failure.  See Note 1
     */
    public static final int _SVC_UNAVAILABLE_NO_RESPONSE =  5;

    /**
     * The Framework has detected that a Service Instance has failed: for example non-response from an activity test, failure to return heartbeats. A permanent failure.  See Note 1
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_NO_RESPONSE = new SvcAvailStatusReason(_SVC_UNAVAILABLE_NO_RESPONSE);

    /**
     * The Service Instance is unavailable due to software  upgrade or other similar maintenance. A permanent failure.  See Note 1.
     */
    public static final int _SVC_UNAVAILABLE_SW_UPGRADE =  6;

    /**
     * The Service Instance is unavailable due to software  upgrade or other similar maintenance. A permanent failure.  See Note 1.
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_SW_UPGRADE = new SvcAvailStatusReason(_SVC_UNAVAILABLE_SW_UPGRADE);

    /**
     * The Service has become available again.
     */
    public static final int _SVC_AVAILABLE =  7;

    /**
     * The Service has become available again.
     */
    public static final SvcAvailStatusReason SVC_AVAILABLE = new SvcAvailStatusReason(_SVC_AVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved SvcAvailStatusReason object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the SvcAvailStatusReason object
     */
    public String getValueText() {
        switch (_value) {
            case _SVC_UNAVAILABLE_UNDEFINED:
                return "SVC_UNAVAILABLE_UNDEFINED";
            case _SVC_UNAVAILABLE_LOCAL_FAILURE:
                return "SVC_UNAVAILABLE_LOCAL_FAILURE";
            case _SVC_UNAVAILABLE_GATEWAY_FAILURE:
                return "SVC_UNAVAILABLE_GATEWAY_FAILURE";
            case _SVC_UNAVAILABLE_OVERLOADED:
                return "SVC_UNAVAILABLE_OVERLOADED";
            case _SVC_UNAVAILABLE_CLOSED:
                return "SVC_UNAVAILABLE_CLOSED";
            case _SVC_UNAVAILABLE_NO_RESPONSE:
                return "SVC_UNAVAILABLE_NO_RESPONSE";
            case _SVC_UNAVAILABLE_SW_UPGRADE:
                return "SVC_UNAVAILABLE_SW_UPGRADE";
            case _SVC_AVAILABLE:
                return "SVC_AVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 7
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static SvcAvailStatusReason getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof SvcAvailStatusReason)) {
            return false;
        }
        SvcAvailStatusReason svcAvailStatusReason = (SvcAvailStatusReason) o; 
        if(!(this.getValue() == svcAvailStatusReason.getValue())) {
            return false;
        }
        if (this.hashCode() != svcAvailStatusReason.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SvcAvailStatusReason

