//Source file: Authentication.java
//Date: June 2004
//Framework Access Interfaces for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw.fw_access.trust_and_security;

/**
 * The Authentication Framework interface is used by client to request access to other interfaces supported by the Framework. The authentication process should in this case be done with some underlying distribution technology authentication mechanism, for example CORBA Security.																				At least one of IpAuthentication or IpAPILevelAuthentication interfaces shall be implemented by a Framework as a minimum requirement.  The requestAccess() method shall be implemented in each.
 *
 */
public interface Authentication extends org.csapi.jr.se.CsapiInterface{

    /**
     * Once the client has been authenticated by the framework, the client may invoke the requestAccess operation on the IpAuthentication or IpAPILevelAuthentication interface. This allows the client to request the type of access they require. If they request P_OSA_ACCESS, then a reference to the IpAccess interface is returned. (Operators can define their own access interfaces to satisfy client requirements for different types of access.)
If this method is called before the client has been successfully authenticated, then the request fails, and an error code (P_ACCESS_DENIED) is returned.
This method may be invoked by the client immediately on IpAuthentication, when API Level authentication is not being used, since there is no indication to the client at API level that it is authenticated with the Framework.
     * @return fwAccessInterface    This provides the reference for the client to call the access interface of the framework. The access reference provided is unique to the requesting client.
     * @param accessType This identifies the type of access interface requested by the client.  If the framework does not provide the type of access identified by accessType, then an error code (P_INVALID_ACCESS_TYPE) is returned.
     * @param clientAccessInterface This provides the reference for the framework to call the access interface of the client.  If the interface reference is not of the correct type, the framework returns an error code (P_INVALID_INTERFACE_TYPE).
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidAccessTypeException     The framework does not support the type of access interface requested by the client.
     * @exception org.csapi.jr.se.InvalidInterfaceTypeException     The interface reference supplied by the client is the wrong type.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    org.csapi.jr.se.CsapiInterface  requestAccess(String accessType, org.csapi.jr.se.CsapiInterface clientAccessInterface) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidAccessTypeException, org.csapi.jr.se.InvalidInterfaceTypeException, org.csapi.jr.se.PlatformException;


} // Authentication

