//Source file: AppFaultManager.java
//Date: June 2004
//Framework to Application Interfaces for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw.fw_application.integrity;

/**
 * This interface is used to inform the application of events that affect the integrity of the Framework, Service or Client Application.  The Fault Management Framework will invoke methods on the Fault Management Application Interface that is specified when the client application obtains the Fault Management interface  that is by use of the obtainInterfaceWithCallback operation on the IpAccess interface
 *
 */
public interface AppFaultManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The framework uses this method to return the result of a client application-requested activity test.
     * @param activityTestID Used by the client application to correlate this response (when it arrives) with the original request.
     * @param activityTestResult The result of the activity test.
     */
    void  activityTestRes(int activityTestID, String activityTestResult);

    /**
     * The framework invokes this method to test that the client application is operational. On receipt of this request, the application must carry out a test on itself, to check that it is operating correctly.  The application reports the test result by invoking the appActivityTestRes method on the IpFaultManager interface.
     * @param activityTestID The identifier provided by the framework to correlate the response (when it arrives) with this request.
     */
    void  appActivityTestReq(int activityTestID);

    /**
     * The framework invokes this method to notify the client application of a failure within the framework. The client application must not continue to use the framework until it has recovered (as indicated by a fwFaultRecoveryInd). 
     * @param fault Specifies the fault that has been detected by the framework.
     */
    void  fwFaultReportInd(org.csapi.jr.se.fw.InterfaceFault fault);

    /**
     * The framework invokes this method to notify the client application that a previously reported fault has been rectified.  The application may then resume using the framework. 
     * @param fault Specifies the fault from which the framework has recovered.
     */
    void  fwFaultRecoveryInd(org.csapi.jr.se.fw.InterfaceFault fault);

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method svcAvailStatusInd shall be used instead, using the new type of reason parameter to inform the Application the reason why the Service is unavailable and also when the Service becomes available again.
The framework invokes this method to inform the client application that it may experience difficulties using its instance of the indicated service.
     * @param serviceID Identifies the affected service.
     * @param reason Identifies the reason why the service is no longer available
     * @deprecated
     */
    void  svcUnavailableInd(String serviceID, org.csapi.jr.se.fw.SvcUnavailReason reason);

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method generateFaultStatisticsRecordRes shall be used instead, using the new identifier to correlate requests and responses.
This method is used by the framework to provide fault statistics to a client application in response to a genFaultStatsRecordReq method invocation on the IpFaultManager interface. 
     * @param faultStatistics The fault statistics record.
     * @param serviceIDs Specifies the framework or services that are included in the general fault statistics record.  If the serviceIDs parameter is an empty list, then the fault statistics are for the framework.
     * @deprecated
     */
    void  genFaultStatsRecordRes(org.csapi.jr.se.fw.FaultStatsRecord faultStatistics, String[] serviceIDs);

    /**
     * The framework invokes this method to inform the client application that it is no longer available.
     * @param reason Identifies the reason why the framework is no longer available
     */
    void  fwUnavailableInd(org.csapi.jr.se.fw.FwUnavailReason reason);

    /**
     * The framework uses this method to indicate that an error occurred during an application-initiated activity test. 
     * @param activityTestID Used by the application to correlate this response (when it arrives) with the original request.
     */
    void  activityTestErr(int activityTestID);

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method generateFaultStatisticsRecordErr shall be used instead, using the new identifier to correlate requests and errors.
This method is used by the framework to indicate an error fulfilling the request to provide fault statistics, in response to a genFaultStatsRecordReq method invocation on the IpFaultManager interface.
     * @param faultStatisticsError The fault statistics error.
     * @param serviceIDs Specifies the framework or services that were included in the general fault statistics record request.  If the serviceIDs parameter is an empty list, then the fault statistics were requested for the framework.
     * @deprecated
     */
    void  genFaultStatsRecordErr(org.csapi.jr.se.fw.FaultStatisticsError faultStatisticsError, String[] serviceIDs);

    /**
     * The framework invokes this method to indicate to the application that the service instance has detected that it is not responding.
     * @param serviceID Specifies the service for which the indication of unavailability was received.
     */
    void  appUnavailableInd(String serviceID);

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method generateFaultStatisticsRecordReq shall be used instead, using the new identifier to correlate requests and responses.
This method is used by the framework to solicit fault statistics from the client application, for example when the framework was asked for these statistics by a service instance by using the genFaultStatsRecordReq operation on the IpFwFaultManager interface. On receipt of this request, the client application must produce a fault statistics record, for the application during the specified time interval, which is returned to the framework using the genFaultStatsRecordRes operation on the IpFaultManager interface. 
     * @param timePeriod The period over which the fault statistics are to be generated. Supplying both a start time and stop time as empty strings leaves the time period to the discretion of the client application.
     * @deprecated
     */
    void  genFaultStatsRecordReq(org.csapi.jr.se.TimeInterval timePeriod);

    /**
     * The framework invokes this method to inform the client application about the Service instance availability status, that is that it can no longer use its instance of the indicated service according to the reason parameter or that the Service Instance becomes available again. On receipt of this request, the client application either acts to reset its use of the specified service (using the normal mechanisms, such as the discovery and authentication interfaces, to stop use of this service instance and begin use of a different service instance). The client application can also wait for the problem to be solved and just stop the usage of the service instance until the svcAvailStatusInd() is called again with the reason SERVICE_AVAILABLE. 
     * @param serviceID Identifies the affected service.
     * @param reason Identifies the reason why the service is no longer available or that it has become available again.
     */
    void  svcAvailStatusInd(String serviceID, org.csapi.jr.se.fw.SvcAvailStatusReason reason);

    /**
     * This method is used by the framework to provide fault statistics to a client application in response to a generateFaultStatisticsRecordReq method invocation on the IpFaultManager interface.
     * @param faultStatsReqID Used by the client application to correlate this response (when it arrives) with the original request.
     * @param faultStatistics The fault statistics record.
     * @param serviceIDs Specifies the framework or services that are included in the general fault statistics record.  If the serviceIDs parameter is an empty list, then the fault statistics are for the framework. 
In the case where a list of services is present, this is an ordered list in which the location of the service in this list corresponds to the location of the related fault statistics in the TpFaultStatsRecord returned.
     */
    void  generateFaultStatisticsRecordRes(int faultStatsReqID, org.csapi.jr.se.fw.FaultStatsRecord faultStatistics, String[] serviceIDs);

    /**
     * This method is used by the framework to indicate an error fulfilling the request to provide fault statistics, in response to a generateFaultStatisticsRecordReq method invocation on the IpFaultManager interface.
     * @param faultStatsReqID Used by the client application to correlate this error (when it arrives) with the original request.
     * @param faultStatistics The list of fault statistics errors returned.
     * @param serviceIDs Specifies the framework or services that are included in the list of fault statistics errors returned.  If the serviceIDs parameter is an empty list, then the fault statistics error relates to the framework.
In the case where a list of services is present, this is an ordered list in which the location of the service in this list corresponds to the location of the related fault statistics error in the TpFaultStatsErrorList returned.
     */
    void  generateFaultStatisticsRecordErr(int faultStatsReqID, org.csapi.jr.se.fw.FaultStatisticsError[] faultStatistics, String[] serviceIDs);

    /**
     * This method is used by the framework to solicit fault statistics from the client application, for example when the framework was asked for these statistics by a service instance by using the generateFaultStatisticsRecordReq operation on the IpFwFaultManager interface. On receipt of this request, the client application must produce a fault statistics record, for the application during the specified time interval, which is returned to the framework using the generateFaultStatisticsRecordRes operation on the IpFaultManager interface. 
     * @param faultStatsReqID The identifier provided by the framework to correlate the response (when it arrives) with this request.
     * @param timePeriod The period over which the fault statistics are to be generated. Supplying both a start time and stop time as empty strings leaves the time period to the discretion of the client application.
     */
    void  generateFaultStatisticsRecordReq(int faultStatsReqID, org.csapi.jr.se.TimeInterval timePeriod);


} // AppFaultManager

