//Source file: LoadManager.java
//Date: June 2004
//Framework to Application Interfaces for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw.fw_application.integrity;

/**
 * The framework API should allow the load to be distributed across multiple machines and across multiple component processes, according to a load management policy. The separation of the load management mechanism and load management policy ensures the flexibility of the load management services. The load management policy identifies what load management rules the framework should follow for the specific client application. It might specify what action the framework should take as the congestion level changes. For example, some real-time critical applications will want to make sure continuous service is maintained, below a given congestion level, at all costs, whereas other services will be satisfied with disconnecting and trying again later if the congestion level rises. Clearly, the load management policy is related to the QoS level to which the application is subscribed.  The framework load management function is represented by the IpLoadManager interface.  Most methods are asynchronous, in that they do not lock a thread into waiting whilst a transaction performs.  To handle responses and reports, the client application developer must implement the IpAppLoadManager interface to provide the callback mechanism.  The application supplies the identity of this callback interface at the time it obtains the framework's load manager interface, by use of the obtainInterfaceWithCallback operation on the IpAccess interface.																If the IpLoadManager interface is implemented by a Framework, at least one of the methods shall be implemented as a minimum requirement. If load level notifications are supported, the createLoadLevelNotification() and destroyLoadLevelNotification() methods shall be implemented.  If suspendNotification() is implemented, then resumeNotification() shall be implemented also.  If a Framework is capable of invoking the IpAppLoadManager.queryAppLoadStatsReq() method, then it shall implement queryAppLoadStatsRes() and queryAppLoadStatsErr() methods in this interface.
 *
 */
public interface LoadManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The client application uses this method to report its current load level (0,1, or 2) to the framework  for example when the load level on the application has changed. 
At level 0 load, the application is performing within its load specifications (that is it is not congested or overloaded). At level 1 load, the application is overloaded.  At level 2 load, the application is severely overloaded.  In addition this method shall be called by the application in order to report current load status, when load notifications are first requested, or resumed after suspension.
     * @param loadLevel Specifies the application's load level.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  reportLoad(org.csapi.jr.se.fw.LoadLevel loadLevel) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryLoadStatsReq shall be used instead, using the new identifier to correlate requests and responses.
The client application uses this method to request the framework to provide load statistic records for the framework or for its instances of the individual services.   If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.
     * @param serviceIDs Specifies the framework or the services for which load statistics records should be reported. If this parameter is not an empty list, the load statistics records of the client's instances of the specified services are returned, otherwise the load statistics record of the framework is returned.
     * @param timeInterval Specifies the time interval for which load statistics records should be reported.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidServiceIdException     Invalid service ID
     * @exception org.csapi.jr.se.fw.ServiceNotEnabledException     The service ID does not correspond to a service that has been enabled
     * @exception org.csapi.jr.se.UnauthorisedParameterValueException     A method parameter value violates the Service Level Agreement.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     * @deprecated
     */
    void  queryLoadReq(String[] serviceIDs, org.csapi.jr.se.TimeInterval timeInterval) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidServiceIdException, org.csapi.jr.se.fw.ServiceNotEnabledException, org.csapi.jr.se.UnauthorisedParameterValueException, org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryAppLoadStatsRes shall be used instead, using the new identifier to correlate requests and responses.
The client application uses this method to send load statistic records back to the framework that requested the information; that is in response to an invocation of the queryAppLoadReq method on the IpAppLoadManager interface.
     * @param loadStatistics Specifies the application-supplied load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     * @deprecated
     */
    void  queryAppLoadRes(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryAppLoadStatsErr shall be used instead, using the new identifier to correlate requests and errors.
The client application uses this method to return an error response to the framework that requested the application's load statistics information, when the application is unsuccessful in obtaining any load statistic records; that is in response to an invocation of the queryAppLoadReq method on the IpAppLoadManager interface.
     * @param loadStatisticsError Specifies the error code associated with the failed attempt to retrieve the application's load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     * @deprecated
     */
    void  queryAppLoadErr(org.csapi.jr.se.fw.LoadStatisticError loadStatisticsError) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to register to receive notifications of load level changes associated with either the framework or with its instances of the individual services used by the application.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.  Upon receipt of this method the framework shall inform the client application of the current framework or service instance load using the loadLevelNotification method on the corresponding IpAppLoadManager.
     * @param serviceIDs Specifies the framework or SCFs to be registered for load control.  To register for framework load control, the serviceIDs parameter must be an empty list.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidServiceIdException     Invalid service ID
     * @exception org.csapi.jr.se.UnauthorisedParameterValueException     A method parameter value violates the Service Level Agreement.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  createLoadLevelNotification(String[] serviceIDs) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidServiceIdException, org.csapi.jr.se.UnauthorisedParameterValueException, org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to unregister for notifications of load level changes associated with either the framework or with its instances of the individual services used by the application.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.
     * @param serviceIDs Specifies the framework or the services for which load level changes should no longer be reported. To unregister for framework load control, the serviceIDs parameter must be an empty list.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidServiceIdException     Invalid service ID
     * @exception org.csapi.jr.se.UnauthorisedParameterValueException     A method parameter value violates the Service Level Agreement.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  destroyLoadLevelNotification(String[] serviceIDs) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidServiceIdException, org.csapi.jr.se.UnauthorisedParameterValueException, org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to request the framework to resume sending it load management notifications associated with either the framework or with its instances of the individual services used by the application; for example after a period of suspension during which the application handled a temporary overload condition.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.  Upon receipt of this method the framework shall inform the client application of the current framework or service instance load using the loadLevelNotification method on the corresponding IpAppLoadManager.
     * @param serviceIDs Specifies the framework or the services for which the sending of notifications of load level changes by the framework should be resumed. To resume notifications for the framework, the serviceIDs parameter must be an empty list.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidServiceIdException     Invalid service ID
     * @exception org.csapi.jr.se.fw.ServiceNotEnabledException     The service ID does not correspond to a service that has been enabled
     * @exception org.csapi.jr.se.UnauthorisedParameterValueException     A method parameter value violates the Service Level Agreement.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  resumeNotification(String[] serviceIDs) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidServiceIdException, org.csapi.jr.se.fw.ServiceNotEnabledException, org.csapi.jr.se.UnauthorisedParameterValueException, org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to request the framework to suspend sending it load management notifications associated with either the framework or with its instances of the individual services used by the application; for example while the application handles a temporary overload condition.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.
     * @param serviceIDs Specifies the framework or the services for which the sending of notifications by the framework should be suspended. To suspend notifications for the framework, the serviceIDs parameter must be an empty list.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidServiceIdException     Invalid service ID
     * @exception org.csapi.jr.se.fw.ServiceNotEnabledException     The service ID does not correspond to a service that has been enabled
     * @exception org.csapi.jr.se.UnauthorisedParameterValueException     A method parameter value violates the Service Level Agreement.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  suspendNotification(String[] serviceIDs) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidServiceIdException, org.csapi.jr.se.fw.ServiceNotEnabledException, org.csapi.jr.se.UnauthorisedParameterValueException, org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to request the framework to provide load statistic records for the framework or for its instances of the individual services.   If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID. 
     * @param loadStatsReqID The identifier provided by the application to correlate the response (when it arrives) with this request.
     * @param serviceIDs Specifies the framework or the services for which load statistics records should be reported. If this parameter is not an empty list, the load statistics records of the client's instances of the specified services are returned, otherwise the load statistics record of the framework is returned.
     * @param timeInterval Specifies the time interval for which load statistics records should be reported.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidServiceIdException     Invalid service ID
     * @exception org.csapi.jr.se.fw.ServiceNotEnabledException     The service ID does not correspond to a service that has been enabled
     * @exception org.csapi.jr.se.UnauthorisedParameterValueException     A method parameter value violates the Service Level Agreement.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  queryLoadStatsReq(int loadStatsReqID, String[] serviceIDs, org.csapi.jr.se.TimeInterval timeInterval) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidServiceIdException, org.csapi.jr.se.fw.ServiceNotEnabledException, org.csapi.jr.se.UnauthorisedParameterValueException, org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to send load statistic records back to the framework that requested the information; that is in response to an invocation of the queryAppLoadStatsReq method on the IpAppLoadManager interface. 
     * @param loadStatsReqID Used by the framework to correlate this response (when it arrives) with the original request.
     * @param loadStatistics Specifies the application-supplied load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  queryAppLoadStatsRes(int loadStatsReqID, org.csapi.jr.se.fw.LoadStatistic[] loadStatistics) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to return an error response to the framework that requested the application's load statistics information, when the application is unsuccessful in obtaining any load statistic records; that is in response to an invocation of the queryAppLoadStatsReq method on the IpAppLoadManager interface.
     * @param loadStatsReqID Used by the framework to correlate this error (when it arrives) with the original request.
     * @param loadStatisticsError Specifies the error code associated with the failed attempt to retrieve the application's load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  queryAppLoadStatsErr(int loadStatsReqID, org.csapi.jr.se.fw.LoadStatisticError loadStatisticsError) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;


} // LoadManager

