//Source file: SvcEventNotification.java
//Date: June 2004
//Framework to Service Interfaces for 3GPP TS 29.198-03 V5.7.0

package org.csapi.jr.se.fw.fw_service.notification;

/**
 * This interface is used by the framework to inform the service of a generic event.  The Event Notification Framework will invoke methods on the Event Notification Service Interface that is specified when the Event Notification interface is obtained.  If Event Notifications are supported by a Service, this interface and the reportNotification() and notificationTerminated() methods shall be supported.
 *
 */
public interface SvcEventNotification extends org.csapi.jr.se.CsapiInterface{

    /**
     * This method notifies the service of the arrival of a generic event.
     * @param eventInfo Specifies specific data associated with this event.
     * @param assignmentID Specifies the assignment id which was returned by the framework during the createNotification() method. The service can use the assignment id to associate events with event specific criteria and to act accordingly.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.InvalidAssignmentIdException     The assignment ID is invalid
     */
    void  reportNotification(org.csapi.jr.se.fw.FwEventInfo eventInfo, int assignmentID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.InvalidAssignmentIdException;

    /**
     * This method indicates to the service that all generic event notifications have been terminated (for example, due to faults detected).
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  notificationTerminated() throws org.csapi.jr.se.CommonException;


} // SvcEventNotification

